@@ -17,6 +17,7 @@ from datadog import initialize, api, util
 from datadog.api import (
     Distribution,
     Event,
+    Logs,
     Metric,
     ServiceCheck,
     User
@@ -604,6 +605,16 @@ class TestEventResource(DatadogAPIWithInitialization):
         assert "Parameter alert_type must be either error, warning, info or success" in str(excinfo.value)
 
 
+class TestLogsResource(DatadogAPIWithInitialization):
+    def test_list_logs(self):
+        Logs.list(data={"time": {"from": "2021-01-01T11:00:00Z", "to": "2021-01-02T11:00:00Z"}})
+        self.request_called_with(
+            "POST",
+            "https://example.com/api/v1/logs-queries/list",
+            data={"time": {"from": "2021-01-01T11:00:00Z", "to": "2021-01-02T11:00:00Z"}}
+        )
+
+
 class TestMetricResource(DatadogAPIWithInitialization):
 
     def submit_and_assess_metric_payload(self, serie, attach_host_name=True):
